@@ -133,7 +133,6 @@ def map_PDB_structure(vep_mapping):
 			structure = structure_list.get(entry)
 			# ensure the expression source
 			org_sys = structure.header['source']['1']['organism_scientific'].replace(' ','').split(',')
-			print(entry,org_sys)
 			if len(org_sys) > 1 or org_sys[0] != 'homosapiens': continue 
 
 			atom  = structure[0][chain][residue]["CA"]
@@ -205,6 +204,7 @@ def parser_vcf(genotype_file,phenotype_file,cov_file,cov_list,freq):
 		cov_raw = pd.read_csv(cov_file,sep='\s+|\t|,',engine='python',index_col=0)
 		cov_raw.dropna(inplace=True)
 		cov = cov_raw.loc[:,cov_list]
+		cov.index   = cov.index.map(str)
 	else: cov = None
 
 	# process phenotype files
