@@ -98,17 +98,6 @@ def run_pokemon():
 	freq_w, struct_w, combined_w = \
 		weight_mat(freqs.values,distance_mat,aa_weight,use_aa=use_blosum_bool,alpha=float(alpha))
 
-	if draw_figures: 
-		from lib.cluster import cluster
-		for lab, ipheno in phenotype.iterrows():
-			out_fig_prefix = figures_dir + '/' + gene_name + '_' + lab  +'_' + pdb
-			ipheno = ipheno.to_frame(lab).T
-			try:
-				cls = cluster(genotype,snps2aa,phenotype,distance_mat,pdb)
-				cls.plot(out_fig_prefix)
-				cls.plot_cluster(out_fig_prefix)
-			except: continue
-
 	# calculate kernel based on the score matrix
 	K = cal_Kernel(combined_w, genotype)
 	m = genotype.shape[1]
@@ -119,14 +108,28 @@ def run_pokemon():
 
 	for lab, ipheno in phenotype.iterrows():
 		temp = ipheno.values.astype(np.float64)
-		try:
-			pval = obj.test(temp, acc=1e-8)	
-			record = [gene_name, pdb,lab, str(pval)]
-			outf.write('\t'.join(record) + '\n')
-		except: continue
+		ipheno_T = ipheno.to_frame(lab).T
+		number_pheno_val = len(unique(temp))
+
+		if (number_pheno_val < 3):
+		        percent_df = percent(genotype,ipheno_T,snps2aa)
+
+		if np.all(percent_df['es']<0.5):
+		        print("all case or control varaints")
+		        continue
+
+		pval = obj.test(temp, acc=1e-8)
+		record = [gene_name, pdb,lab, str(pval)]
+		outf.write('\t'.join(record) + '\n')
+		if pval > 0.05: continue
+		if draw_figures and (number_pheno_val < 3):
+		        from lib.cluster import cluster
+		        out_fig_prefix = figures_dir + '/' + gene_name + '_' + lab  +'_' + pdb
+		        cls = cluster(genotype,snps2aa,ipheno_T,distance_mat,pdb)
+		        cls.plot(out_fig_prefix)
+		        cls.plot_cluster(out_fig_prefix)
 
 if __name__ == "__main__":
 	run_pokemon()
 
 
-
